/***************************
  DIO24-ARD Read Example
****************************/

// Must specify the Arduino SPI library
#include <SPI.h>

// Declare program constants
const int DIO24_Select = 10;   // Pin used as board enable, *** MUST MATCH J2 SETTING ON DIO24-ARD
const byte CMD_RD = 0x01;      // Read Command

// Variables to hold the port states (i.e.; values) after reading  
byte porta_rd_value;  //Holds 8-bit data retrieved from porta 
byte portb_rd_value;  //Holds 8-bit data retrieved from portb
byte portc_rd_value;  //Holds 8-bit data retrieved from portc

// Perform Program Initialization
void setup() {
   SPI.begin();                          // Initialize SPI
   pinMode(DIO24_Select, OUTPUT);         // Set DIO24_Select as an output
   digitalWrite(DIO24_Select, HIGH);      // De-Select the DIO24-ARD
 
   // Open serial communications and wait for port to open: 
   Serial.begin(9600);
   while (!Serial) {
    ; // wait for serial port to connect. Needed for Leonardo only
   }  
}

// --- This is the Main Loop, repeats indefinitely
void loop() {
 
   // Read the three ports and store their states
   digitalWrite(DIO24_Select, LOW);      // Step 1, Select the DIO24-ARD 
   SPI.transfer(CMD_RD);                 // Step 2, Send 1st byte: Read Command, discard returned byte
   porta_rd_value = SPI.transfer(0x00);  // Step 3, Send 2nd byte: data sent is "Don't Care", returns state of PORTA
   portb_rd_value = SPI.transfer(0x00);  // Step 4, Send 3rd byte: data sent is "Don't Care", returns state of PORTB
   portc_rd_value = SPI.transfer(0x00);  // Step 5, Send 4th byte: data sent is "Don't Care", returns state of PORTC
   digitalWrite(DIO24_Select, HIGH);     // Step 6, De-Select the DIO24-ARD

   // Display the results on user screen using Arduino IDE Serial Monitor
   Serial.print("PORTA: ");                // Show porta as binary
   Serial.print(porta_rd_value, BIN);         
   
   Serial.print("  PORTB: ");              // Show portb as binary
   Serial.print(portb_rd_value, BIN);  
   
   Serial.print("  PORTC: ");              // Show portc as binary
   Serial.println(portc_rd_value, BIN);  
}


